#!/bin/bash
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
#
# Written by Vidar Jon Bauge, vidarjon@tiscali.dk
#
# Version 0.12 29.03.2006

#Filebrowser to access the device
#
#########################################################################################
filebrowser="rox"
#Language specific variables
#
################################################################################

#English
menutext1="Browse in "
menutext2=" the device"
menutext3="Eject the device"
device="Device "
device1="The device "
vName="Volume name: "
alternativs="Alternatives for "
success="succeeded"
browse="Browse "
ejects="Eject "
cancelled="Cancelled"
esc="ESC pressed"
result="Result of "
notFound=" not found"
warnSupermount="One or more of the devices, are controlled by supermount. This interferes with the functionality of this program!"
usbDevices="USB Devices"
usbSystem="USB Devices in the system:"
IsMounted="Mounted    "
IsNotMounted="Unmounted "

#Danish
#menutext1="Se igennem i "
#menutext2=" enheden"
#menutext3="Ls ud enheden"
#device="Enhed "
#device1="Enheden "
#vName="Volumnavn: "
#alternativs="Alternativer for "
#success="vellykket"
#browse="Se igennem "
#ejects="Ls ud "
#cancelled="Afbrudt"
#esc="ESC trykket"
#result="Resultat af "
#warnSupermount="En eller flere enheder er kontrolleret af supermount. Dette kan ophve nogle af mounters funktioner!"
#usbDevices="USB Enheder"
#usbSystem="Tilgngelige usb enheter:"
#IsMounted="Monteret    "
#IsNotMounted="Afmonteret "

#Norwegian
#menutext1="Se gjennom i "
#menutext2=" enheten"
#menutext3="Ls ut enheten"
#device="Enhet "
#device1="Enheten "
#vName="Volumnavn: "
#alternativs="Alternativer for "
#success="vellykket"
#browse="Se igjennom "
#ejects="Ls ut "
#cancelled="Avbrudt"
#esc="ESC trykket"
#result="Resultat av "
#warnSupermount="En eller flere enheter er kontrollert av supermount. Dette kan opheve noen av mounters funksjoner!"
#usbDevices="USB Enheter"
#usbSystem="Tilgjengelige usb enheter:"
#IsMounted="Montert    "
#IsNotMounted="Avmontert "

#System specific variables
#
################################################################################

resultString=""
MenuItem1="Mount"
actionString="mount"
mountDevice=""
mntString=""
devStr=""
usbStatus=""
ifcdrom=""
DIALOG="Xdialog"
tmpfile="/tmp/tempMounter.$$"

#First make sure Xdialog is available
#######################################################################################

which $DIALOG &> $tmpfile
if cat $tmpfile | grep "no Xdialog in" > /dev/null ; then
	echo "ERROR: Xdialog not installed or not in path. Try http://xdialog.dyns.net/"
	exitMounter
fi
rm -f $tmpfile

#Subroutine that shows an error message, if there is one
################################################################################

tempfile=`tempfile 2>/dev/null` || tempfile=/tmp/tmpMountDevice$$
trap "rm -f $tempfile" 0 1 2 5 15

showResult()
{
	if [ ! -z "$resultString" ]; then
		len=${#resultString}
		len=len+4
		$DIALOG --title "$result $actionString" \
        	--msgbox "$resultString" 10 len
	fi
	resultString=""
}

#Make sure the chosen file browser is available
#######################################################################################

which $filebrowser &> $tmpfile
if cat $tmpfile | grep "no $filebrowser in" > /dev/null ; then
	resultString=$browserNotFound
	showResult
fi
rm -f $tmpfile

#		Delete temp file and exit script
################################################################################

exitMounter() 
{

rm -f $tmpfile
exit

}

#Device to handle
#Parse command parameters, determine mount poin from /etc/fstab
################################################################################

if [ -z "$1" ]; then
	echo "mounter usb|-usb|device|mountpoint"
	echo "usage:"
	echo "mounter mountpoint, which is a device or a mountpoint"
	echo "mounter usb to autodetect usb devices on system"
	exitMounter
fi

superM=$(grep "supermount" /etc/fstab)

if [ ! -z "$superM" ]; then
	echo $warnSupermount
	echo
fi

devString=$1

if [ "$devString" = "usb" -o "$devString" = "-usb" ]; then

	deviceList=$(grep /dev/sd /etc/fstab)
	if [ -z "$deviceList" ]; then
		echo "No usb devices found"
		resultString="No usb devices found"
		showResult
		exitMounter
	fi

	#Find all available usb devices on system
	#and place in:
	#Number of devices: numberOfDevices
	#devices: array devString[]
	#mount points: array mntString[]
	#
	############################################################################

	numberOfDevices=0
	IFS=" "
	exec < /etc/fstab
	while read device mountpoint field3 field4 field5 field6; \
	do
		if [ `expr "$device" : '/dev/sd'` = 7 ]; then
			echo usb-device $numberOfDevices - $device at $mountpoint
			devString[$numberOfDevices]=$device
			mntString[$numberOfDevices]=$mountpoint
						
			mounted=$(grep ${devString[$numberOfDevices]} /etc/mtab)
			
			if [ -z "$mounted" ];then
				mntString[$numberOfDevices]="$IsNotMounted ${mntString[$numberOfDevices]}"
				
			else
				mntString[$numberOfDevices]="$IsMounted ${mntString[$numberOfDevices]}"
			fi
			((numberOfDevices = numberOfDevices + 1))
		fi

	done \
		
	#Dialogue to choose which usb device to work on
	#
	############################################################################

	if [ "$numberOfDevices" -eq "1" ] ; then
		devString=${devString[0]}
	else
		tempfile=`tempfile 2>/dev/null` || tempfile=/tmp/tmpMountDevice$$
		trap "rm -f $tempfile" 0 1 2 5 15
	
		$DIALOG --title "$usbDevices" \
	        --menu "$usbSystem" 22 40 4 \
			${devString[0]} ${mntString[0]} \
			${devString[1]} ${mntString[1]} \
			${devString[2]} ${mntString[2]} \
			${devString[3]} ${mntString[3]} \
			${devString[4]} ${mntString[4]} \
			${devString[5]} ${mntString[5]} \
			${devString[6]} ${mntString[6]} \
	        ${devString[7]} ${mntString[7]} \
			${devString[8]} ${mntString[8]} \
			${devString[9]} ${mntString[9]}  2> $tempfile
		
		retval=$?

		case $retval in
  		0)
  			choice=`cat $tempfile`
    		case $choice in
			${devString[0]}) devString=${devString[0]} \
			;;
			${devString[1]}) devString=${devString[1]} \
			;;
			${devString[2]}) devString=${devString[2]} \
			;;
			${devString[3]}) devString=${devString[3]} \
			;;
			${devString[4]}) devString=${devString[4]} \
			;;
			${devString[5]}) devString=${devString[5]} \
			;;
			${devString[6]}) devString=${devString[6]} \
    	    ;;
			${devString[7]}) devString=${devString[7]} \
			;;
			${devString[8]}) devString=${devString[8]} \
			;;
			${devString[9]}) devString=${devString[9]} \
			;;
		
		esac
			;;
		1)
    		echo "$cancelled"
			exitMounter
			;;
  		255)
    		echo "$esc"
			exitMounter
			;;
		esac
	fi
fi

IFS=" "
exec < /etc/fstab
while read device mountpoint filesys field4 field5 field6; \
do
	if [ "$device" = "$devString" -o "$mountpoint" = "$devString" ]; then
		mountDevice=$device
		mntString=$mountpoint
		filesystem=$filesys
		
	fi
done \

if [ -z "$mntString" ]; then
	resultString=$device1" "$1" "$notFound
	showResult
	exitMounter
fi

#Check to see whether the device exists, and if it ismounted or not, and set the 
#mount/umount command according the result
################################################################################

mounted=$(grep $mountDevice /etc/mtab)
		
	if [ -z "$mounted" ]; then
		MenuItem1="Mount"
		actionString="mount"
	else
		MenuItem1="Umount"
		actionString="umount"
	fi


#Determine whether device is a cdrom/dvd, and therefore ejectable
#This will work on a system with up to 9 cdroms/dvds
################################################################################

declare -i cdlength

cdrom=$(basename $mntString)
cdlength=${#cdrom}
((cdlength = cdlength - 1))
cdrom1=${cdrom:0:$cdlength}

if [ "$cdrom" = "cdrom" -o "$cdrom1" = "cdrom" ];then
	ifcdrom="yes"
elif [ "$cdrom" = "dvd" -o "$cdrom1" = "dvd" ];then
	ifcdrom="yes"
fi


#		Open device in the chosen file browser
################################################################################

browse()
{
	#First check to see whether the device is to be mounted and
	#mount it if nessecary
	if [ $actionString = "mount" ]; then
		$actionString $mntString
	fi
		
	$filebrowser $mntString 
	exitMounter
}


#		Mount/Umount the device
################################################################################

mounting()
{
	$actionString $mountDevice 2>&1 | tee > $tempfile
	resultString=`cat $tempfile`
	rm -f $tempfile
	if [ -z "$resultString" ]; then
		resultString=$actionString" "$success
	fi
	showResult
	exitMounter
}

#		Eject the device
################################################################################

ejecting() 
{
	eject $mountDevice 2>&1 | tee > $tempfile
	resultString=`cat $tempfile`
	rm -f $tempfile
	if [ -z "$resultString" ]; then
		resultString=eject" "$success
	fi
	showResult
	exitMounter
}

#Open the main meu
#
################################################################################

#Read volume name, If there is one, set variable headerString and adjust box heigth
devName=$(volname $mountDevice)
declare -i height

if [ -z "$devName" ];then
	headerString="$alternativs $mntString"
	heigth=10
else
	headerString="$alternativs $mntString\n$vName$devName"
	heigth=12
fi

if [ "$ifcdrom" = "yes" ]; then

	$DIALOG --clear --title "$mntString" \
	        --menu "$headerString" $heigth 40 4 \
	        "$browse"  "$menutext1 $filebrowser" \
	        "$MenuItem1" "$MenuItem1 $menutext2" \
	        "$ejects" "$menutext3"  2> $tempfile
			
	retval=$?
	
	case $retval in
	  0)
	  	choice=`cat $tempfile`
	    case $choice in
			"$browse") browse
			;;
			"$MenuItem1") mounting
			;;
			"$ejects") ejecting
			;;
		esac
		;;
	  1)
	    echo "$cancelled";;
	  255)
	    echo "$esc";;
	esac
	
else

	$DIALOG --clear --title "$mntString" \
	        --menu "$headerString" $heigth 40 4 \
	        "$browse"  "$menutext1 $filebrowser" \
	        "$MenuItem1" "$MenuItem1 $menutext2"   2> $tempfile
			
	retval=$?
	
	case $retval in
	  0)
	  	choice=`cat $tempfile`
	    case $choice in
			"$browse") browse
			;;
			"$MenuItem1") mounting
			;;
		esac
		;;
	  1)
	    echo "$cancelled";;
	  255)
	    echo "$esc";;
	esac

fi

exitMounter
